==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/equipment/armor/CardboardArmorHandler.java <==
package com.zurrtum.create.content.equipment.armor;

import com.zurrtum.create.AllAdvancements;
import net.minecraft.class_10583;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1405;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4048;
import net.minecraft.class_4050;
import net.minecraft.class_4135;
import net.minecraft.class_5354;
import net.minecraft.class_9066;
import net.minecraft.world.entity.*;

public class CardboardArmorHandler {
    public static class_4048 playerHitboxChangesWhenHidingAsBox(class_1297 entity) {
        if (!testForStealth(entity))
            return null;
        if (!testForStealth(entity))
            return null;
        float scale;
        if (entity instanceof class_1309 le) {
            scale = le.method_55693();
        } else {
            scale = 1.0F;
        }

        if (!entity.method_73183().method_8608() && entity instanceof class_3222 serverPlayer) {
            AllAdvancements.CARDBOARD_ARMOR.trigger(serverPlayer);
        }

        float width = 0.6F * scale;
        float height = 0.8F * scale;
        return new class_4048(width, height, width, class_9066.method_55844(width, height), true);
    }

    public static void playerChangesEquipment(class_1657 player) {
        if (player.method_18376() == class_4050.field_18081 && (isCardboardArmor(player.method_6118(class_1304.field_6169)) || isCardboardArmor(player.method_6118(
            class_1304.field_6174)) || isCardboardArmor(player.method_6118(class_1304.field_6172)) || isCardboardArmor(player.method_6118(class_1304.field_6166)))) {
            player.method_5841().method_49743(class_1297.field_18064, class_4050.field_18081, true);
        }
    }

    public static void mobsMayLoseTargetWhenItIsWearingCardboard(class_1297 entity) {
        if (!(entity instanceof class_1308 mob))
            return;
        if (mob.field_6012 % 16 != 0)
            return;

        if (testForStealth(mob.method_5968())) {
            mob.method_5980(null);
            if (mob.field_6185 != null)
                for (class_4135 goal : mob.field_6185.method_35115()) {
                    if (goal.method_19056() && goal.method_19058() instanceof class_1405 tg)
                        tg.method_6270();
                }
        }

        if (entity instanceof class_5354 nMob && entity.method_73183() instanceof class_3218 sl) {
            class_1309 target = class_10583.method_73301(nMob.method_29508(), sl);
            if (testForStealth(target))
                nMob.method_29922();
        }

        if (testForStealth(mob.method_6065())) {
            mob.method_6015(null);
            mob.method_29505((class_10583<class_1657>) null, 0);
        }
    }

    public static boolean testForStealth(class_1297 entityIn) {
        if (!(entityIn instanceof class_1309 entity))
            return false;
        if (entity.method_18376() != class_4050.field_18081)
            return false;
        if (entity instanceof class_1657 player && player.method_31549().field_7479)
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6169)))
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6174)))
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6172)))
            return false;
        return isCardboardArmor(entity.method_6118(class_1304.field_6166));
    }

    public static boolean isCardboardArmor(class_1799 stack) {
        return stack.method_7909() instanceof CardboardArmorItem;
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/content/equipment/armor/CardboardArmorHandler.java <==
package com.zurrtum.create.content.equipment.armor;

import com.zurrtum.create.AllAdvancements;
import net.minecraft.class_10583;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1405;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_4048;
import net.minecraft.class_4050;
import net.minecraft.class_4135;
import net.minecraft.class_5354;
import net.minecraft.class_9066;
import net.minecraft.entity.*;
import java.util.UUID;

public class CardboardArmorHandler {
    public static class_4048 playerHitboxChangesWhenHidingAsBox(class_1297 entity) {
        if (!testForStealth(entity))
            return null;
        if (!testForStealth(entity))
            return null;
        float scale;
        if (entity instanceof class_1309 le) {
            scale = le.method_55693();
        } else {
            scale = 1.0F;
        }

        if (!entity.method_37908().field_9236 && entity instanceof class_3222 serverPlayer) {
            AllAdvancements.CARDBOARD_ARMOR.trigger(serverPlayer);
        }

        float width = 0.6F * scale;
        float height = 0.8F * scale;
        return new class_4048(width, height, width, class_9066.method_55844(width, height), true);
    }

    public static void playerChangesEquipment(class_1657 player) {
        if (player.method_18376() == class_4050.field_18081 && (isCardboardArmor(player.method_6118(class_1304.field_6169)) || isCardboardArmor(player.method_6118(
            class_1304.field_6174)) || isCardboardArmor(player.method_6118(class_1304.field_6172)) || isCardboardArmor(player.method_6118(
            class_1304.field_6166)))) {
            player.method_5841().method_49743(class_1297.field_18064, class_4050.field_18081, true);
        }
    }

    public static void mobsMayLoseTargetWhenItIsWearingCardboard(class_1297 entity) {
        if (!(entity instanceof class_1308 mob))
            return;
        if (mob.field_6012 % 16 != 0)
            return;

        if (testForStealth(mob.method_5968())) {
            mob.method_5980(null);
            if (mob.field_6185 != null)
                for (class_4135 goal : mob.field_6185.method_35115()) {
                    if (goal.method_19056() && goal.method_19058() instanceof class_1405 tg)
                        tg.method_6270();
                }
        }

        if (entity instanceof class_5354 nMob && entity.method_37908() instanceof class_3218 sl) {
            UUID uuid = nMob.method_29508();
            if (uuid != null && testForStealth(sl.method_66347(uuid)))
                nMob.method_29922();
        }

        if (testForStealth(mob.method_6065())) {
            mob.method_6015(null);
            mob.method_29505((class_10583<class_1657>) null, 0);
        }
    }

    public static boolean testForStealth(class_1297 entityIn) {
        if (!(entityIn instanceof class_1309 entity))
            return false;
        if (entity.method_18376() != class_4050.field_18081)
            return false;
        if (entity instanceof class_1657 player && player.method_31549().field_7479)
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6169)))
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6174)))
            return false;
        if (!isCardboardArmor(entity.method_6118(class_1304.field_6172)))
            return false;
        return isCardboardArmor(entity.method_6118(class_1304.field_6166));
    }

    public static boolean isCardboardArmor(class_1799 stack) {
        return stack.method_7909() instanceof CardboardArmorItem;
    }
}
